/*
** Copyright (c) 2000 by Software Daten Service GesmbH
** Handelskai 94-96, 1200 Vienna,  AUSTRIA
**
** THIS SOFTWARE IS PROVIDED AS-IS WITHOUT WARRANTY OF ANY KIND,
** NOT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY. THE AUTHOR
** OF THIS SOFTWARE, ASSUMES _NO_ RESPONSIBILITY FOR ANY
** CONSEQUENCE RESULTING FROM THE USE, MODIFICATION, OR
** REDISTRIBUTION OF THIS SOFTWARE.
*/

package junit.extensions;

import java.io.IOException;
import java.util.*;

import junit.framework.*;
import junit.properties.*;

/**
 * Base class for test case which are configured using a configuration file
 * instead of hardcoding test data in the fixture. The configuration file can
 * be defined in the system property "junit.data".
 * <br>
 * The entries are searched in the following was :
 * <ul>
 * <li>class name + name of test + key
 * <li>class name without package name + name of test + key
 * <li>class name without package name + key
 * <li>key
 * </ul>
 * <br>
 * @author  Siegfried GOESCHL
 * @version $Id: RepositoryImpl.java,v 1.1.1.1 1999/04/23 11:43:22 wdsgoe Exp $
 */

public class ConfigurableTestCase extends TestCase implements ConfigurableTest {

	 public ConfigurableTestCase(String name) {
        super(name);
        initTestProperties( this.getClass() );
    }

    /**
     * In case of a master test suite it is necessarry to preload the
     * test properties since no instance of the master test case is created
     * usually. In this case no constructor is executed therefore we don't
     * know the class name of the master test casse
     *
     * @param testClass class object of master test case
     */

    static protected void initTestProperties( Class testClass ) {
        TestPropertiesFactory.init( testClass );
    }

    private TestProperties getTestProperties() {
        return TestPropertiesFactory.getSingleton().getTestProperties();
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public boolean getBoolean( String key ) throws IllegalArgumentException {
        return getTestProperties().getBoolean( this, name(), key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public char getChar( String key ) throws IllegalArgumentException {
        return getTestProperties().getChar( this, name(), key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public byte getByte( String key ) throws IllegalArgumentException {
        return getTestProperties().getByte( this, name(), key );
    }


    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public short getShort( String key ) throws IllegalArgumentException {
        return getTestProperties().getShort( this, name(), key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public int getInteger( String key ) throws IllegalArgumentException {
        return getTestProperties().getInteger( this, name(), key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public long getLong( String key ) throws IllegalArgumentException {
        return getTestProperties().getLong( this, name(), key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public String getString( String key ) throws IllegalArgumentException {
        return getTestProperties().getString( this, name(), key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public float getFloat( String key ) throws IllegalArgumentException {
        return getTestProperties().getFloat( this, name(), key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public double getDouble( String key ) throws IllegalArgumentException {
        return getTestProperties().getDouble( this, name(), key );
    }
}