/*
** Copyright (c) 2000 by Software Daten Service GesmbH
** Handelskai 94-96, 1200 Vienna,  AUSTRIA
**
** THIS SOFTWARE IS PROVIDED AS-IS WITHOUT WARRANTY OF ANY KIND,
** NOT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY. THE AUTHOR
** OF THIS SOFTWARE, ASSUMES _NO_ RESPONSIBILITY FOR ANY
** CONSEQUENCE RESULTING FROM THE USE, MODIFICATION, OR
** REDISTRIBUTION OF THIS SOFTWARE.
*/

package junit.extensions;

import junit.framework.*;
import junit.properties.*;

/**
 * A Decorator to set up and tear down additional fixture state with access
 * to TestProperties
 *
 * @author  Siegfried GOESCHL
 * @version $Id: RepositoryImpl.java,v 1.1.1.1 1999/04/23 11:43:22 wdsgoe Exp $
 */

 public class ConfigurableTestSetup extends TestSetup implements ConfigurableTest {

    /**
     * We can't initialize the test properties in the constructor otherwise
     * we would have to define an additional configuration file
     */

	public ConfigurableTestSetup(Test test) {
		super(test);
	}

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public boolean getBoolean( String key ) throws IllegalArgumentException {
        return getTestProperties().getBoolean( this, null, key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public char getChar( String key ) throws IllegalArgumentException {
        return getTestProperties().getChar( this, null, key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public byte getByte( String key ) throws IllegalArgumentException {
        return getTestProperties().getByte( this, null, key );
    }


    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public short getShort( String key ) throws IllegalArgumentException {
        return getTestProperties().getShort( this, null, key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public int getInteger( String key ) throws IllegalArgumentException {
        return getTestProperties().getInteger( this, null, key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public long getLong( String key ) throws IllegalArgumentException {
        return getTestProperties().getLong( this, null, key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public String getString( String key ) throws IllegalArgumentException {
        return getTestProperties().getString( this, null, key );
    }

    /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public float getFloat( String key ) throws IllegalArgumentException {
        return getTestProperties().getFloat( this, null, key );
    }

     /**
     * Retrieve a value from the test data repository
     *
     * @param key key
     * @return value
     * @exception IllegalArgumentException key not found
     */

    public double getDouble( String key ) throws IllegalArgumentException {
        return getTestProperties().getDouble( this, null, key );
    }

    private TestProperties getTestProperties() {
        return TestPropertiesFactory.getSingleton().getTestProperties();
    }
}