/*
** Copyright (c) 2000 by Software Daten Service GesmbH
** Handelskai 94-96, 1200 Vienna,  AUSTRIA
**
** THIS SOFTWARE IS PROVIDED AS-IS WITHOUT WARRANTY OF ANY KIND,
** NOT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY. THE AUTHOR
** OF THIS SOFTWARE, ASSUMES _NO_ RESPONSIBILITY FOR ANY
** CONSEQUENCE RESULTING FROM THE USE, MODIFICATION, OR
** REDISTRIBUTION OF THIS SOFTWARE.
*/

package junit.extensions;

import junit.framework.*;

/**
 * Thread class to execute a test suite
 */

class TestThread extends Thread
{
    Test            suite           = null;
    TestResult      result          = null;

    TestThread ( Test suite, TestResult result )
    {
        this.suite           = suite;
        this.result          = result;
    }

    public void run()
    {
        suite.run( result );
    }
}

/**
 * A Decorator that runs a test in a separate thread.
 *
 * @author  Siegfried GOESCHL
 * @version $Id: RepositoryImpl.java,v 1.1.1.1 1999/04/23 11:43:22 wdsgoe Exp $
 */

public class VeryActiveTest extends TestDecorator {

    int lim = 1;
    Test test = null;

	public VeryActiveTest(Test test ) {
		super(test);
        this.lim = 1;
        this.test = test;
	}

	public VeryActiveTest(Test test, int lim ) {
		super(test);
        this.lim = lim;
        this.test = test;
	}

	public String toString() {
		return super.toString()+"(active)";
	}

	public void run(TestResult result ) {

         TestThread[] threads = new TestThread[lim];

        // create threads

        for( int i=0; i<lim; i++ )
        {
            threads[i] = new TestThread( test, result );
        }

        // start threads

        for( int i=0; i<lim; i++ )
        {
            threads[i].start();
        }

        // wait for termination

        for( int i=0; i<lim; i++ )
        {
            try
            {
               threads[i].join();
            }

            catch( InterruptedException e )
            {
            }
        }
    }
}