/*
** Copyright (c) 2000 by Software Daten Service GesmbH
** Handelskai 94-96, 1200 Vienna,  AUSTRIA
**
** THIS SOFTWARE IS PROVIDED AS-IS WITHOUT WARRANTY OF ANY KIND,
** NOT EVEN THE IMPLIED WARRANTY OF MERCHANTABILITY. THE AUTHOR
** OF THIS SOFTWARE, ASSUMES _NO_ RESPONSIBILITY FOR ANY
** CONSEQUENCE RESULTING FROM THE USE, MODIFICATION, OR
** REDISTRIBUTION OF THIS SOFTWARE.
*/

package junit.tests.extensions;

/**
 * Test class for accessing TestProperties via ConfigurableTestCase
 *
 * @author  Siegfried GOESCHL
 * @version $Id: RepositoryImpl.java,v 1.1.1.1 1999/04/23 11:43:22 wdsgoe Exp $
 */

import java.util.Random;
import junit.framework.*;
import junit.extensions.*;

public class ConfigurableTestCaseTest extends ConfigurableTestCase {

    public ConfigurableTestCaseTest( String name ) {
        super(name);
    }

    public static void main(String args[]) {
        junit.textui.TestRunner.run( ConfigurableTestCaseTest.suite() );
    }

    public static Test suite() {
        TestSuite suite= new TestSuite();
        suite.addTest( new ConfigurableTestCaseTest( "testGetKeyWithBaseNameKey" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testgetKeyWithBaseKey" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetKeyWithKey" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetKeyWithClassNameKey" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetInteger" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetUndefinedKey" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetChar" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetBoolean" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetByte" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetShort" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetLong" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetFloat" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testGetDouble" ) );
        suite.addTest( new ConfigurableTestCaseTest( "testRandomWait" ) );

        return suite;
    }

    /**
     *  Retrieve a value with full key name : base + name + key
     */

    public void testGetKeyWithBaseNameKey() {
        assert( getString( "key1" ).equals( "key1" ) );
    }

    /**
     *  Retrieve a value with base + key
     */

    public void testgetKeyWithBaseKey() {
        assert( getString( "key2" ).equals( "key2" ) );
    }

    /**
     *  Retrieve a value with full key name : class + name + key
     */

    public void testGetKeyWithClassNameKey() {
        assert( getString( "key3" ).equals( "key3" ) );
    }

    /**
     *  Retrieve a value with a key only
     */

    public void testGetKeyWithKey() {
        assert( getString( "key4" ).equals( "key4" ) );
    }

    /**
     *  Retrieve a value with full key name : class + name + key
     */

    public void testGetInteger() {
        assert( getInteger( "key" ) == 9999 );
    }

    /**
     *  Retrieve a value with a key which is not defiend
     */

    public void testGetUndefinedKey() {
        try {
            int result = getInteger( "key" );
        }

        catch( IllegalArgumentException e ) {
            return;
        }

        fail();
    }

    /**
     * Test access of TestProperties
     */

    public void testGetBoolean() {
        assert( getBoolean( "key" ) == true );
    }


    /**
     * Test access of TestProperties
     */

    public void testGetChar() {
        assert( getChar( "key" ) == 'c' );
    }

    /**
     * Test access of TestProperties
     */

    public void testGetByte() {
        assert( getByte( "key" ) == 13 );
    }

    /**
     * Test access of TestProperties
     */

    public void testGetShort() {
        assert( getShort( "key" ) == 1234 );
    }

    /**
     * Test access of TestProperties
     */

    public void testGetLong() {
        assert( getLong( "key" ) == 99999999 );
    }

    /**
     * Test access of TestProperties
     */

    public void testGetFloat() {
        assert( getFloat( "key" ) == (float) 3.12 );
    }

    /**
     * Test access of TestProperties
     */

    public void testGetDouble() {
        assert( getDouble( "key" ) == 3.1214927 );
    }

    public void testRandomWait()
    {
        Random rand = new Random( System.currentTimeMillis() );
        long ms = (long) rand.nextInt( 500 );

        try {
            Thread.currentThread().sleep( ms  );
        }
        catch( InterruptedException e) {
            return;
        }
    }
}
